@@ -1177,7 +1177,6 @@ class Security:
         oauth: t.Optional["OAuth"] = None,
         **kwargs: t.Any,
     ):
-
         # to be nice and hopefully avoid backwards compat issues - we still accept
         # kwargs - but we don't do anything with them. If caller sends in some -
         # output a deprecation warning
@@ -1185,6 +1184,7 @@ class Security:
             warnings.warn(
                 "kwargs passed to the constructor are now ignored",
                 DeprecationWarning,
+                stacklevel=4,
             )
         self.app = app
         self._datastore = datastore
@@ -1461,6 +1461,7 @@ class Security:
                 " and will be removed in the future. Please use the Unified Signin"
                 " feature instead.",
                 DeprecationWarning,
+                stacklevel=2,
             )
         if cv("USERNAME_ENABLE", app):
             if hasattr(self.datastore, "user_model") and not hasattr(
@@ -1470,20 +1471,6 @@ class Security:
                     "User model must contain 'username' if"
                     " SECURITY_USERNAME_ENABLE is True"
                 )
-            # if they want USERNAME_ENABLE - then they better not have defined
-            # username in their own forms
-            if any(
-                hasattr(self.forms[f].cls, "username")
-                for f in [
-                    "register_form",
-                    "confirm_register_form",
-                    "login_form",
-                ]
-            ):  # pragma: no cover
-                raise ValueError(
-                    "Your login_form or register_form has a"
-                    " 'username' attribute already"
-                )
             # if not already listed in user identity attributes, add it at the end
             uialist = []
             for uia in cv("USER_IDENTITY_ATTRIBUTES", app=app):
@@ -1569,7 +1556,8 @@ class Security:
                 warnings.warn(
                     "'sms' was enabled in SECURITY_US_ENABLED_METHODS;"
                     " however 'us_phone_number' not configured in"
-                    " SECURITY_USER_IDENTITY_ATTRIBUTES"
+                    " SECURITY_USER_IDENTITY_ATTRIBUTES",
+                    stacklevel=2,
                 )
         if cv("TWO_FACTOR", app=app):
             alt_auth = True
@@ -1884,6 +1872,7 @@ class Security:
             "'unauthorized_handler' has been replaced with"
             " 'unauthz_handler' and 'unauthn_handler'",
             DeprecationWarning,
+            stacklevel=2,
         )
         self._unauthorized_callback = cb
 
